;;; ljcustom.el --- Custom definitions for ljupdate

;; Copyright (C) 2002  Edward O'Connor <ted@oconnor.cx>

;; Author: Edward O'Connor <ted@oconnor.cx>
;; Keywords: convenience

;; This file is part of ljupdate.

;; ljupdate is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; {at your option} any later version.

;; ljupdate is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public
;; License along with ljupdate, or with your Emacs. See the file
;; COPYING, or, if you're using GNU Emacs, try typing C-h C-c to
;; bring it up. If you're using XEmacs, C-h C-l does this. If you
;; do not have a copy, you can obtain one by writing to the Free
;; Software Foundation at this address:

;;                Free Software Foundation, Inc.
;;                59 Temple Place, Suite 330
;;                Boston, MA  02111-1307
;;                USA

;;; Commentary:

;; 

;;; Code:

(defgroup ljupdate nil
  "Blah blah blah."
  :tag "LiveJournal"
  :link '(url-link "http://www.freesoftware.fsf.org/ljupdate/")
  :link '(url-link "http://www.livejournal.com/community/ljupdate/")
  :prefix "lj-"
  :group 'applications)

(defcustom lj-message-level 4
  "Verbosity level for ljupdate.

This should be a number from 0 to 9 inclusive. Larger numbers mean
more verbosity. Generally speaking, errors will be reported at
level 1. Normal user messages are level 2, while debugging
messages are level 6. Very large debugging messages are level 9.

So if you never want to hear anything at all (this is not a good
idea), set this to 0. The default of 4 is the recommended value."
  :type 'integer
  :group 'ljupdate)

(defcustom lj-default-system 'livejournal
  "*The LiveJournal system to post updates to by default."
  :type '(choice (restricted-sexp :match-alternatives (lj-system-p))
                 (set (restricted-sexp :match-alternatives (lj-system-p))))
  :group 'ljupdate)

(defcustom lj-default-profile nil
  "*The profile (or profiles) to use by default."
  :type '(choice (restricted-sexp :match-alternatives (lj-profile-p))
                 (set (restricted-sexp :match-alternatives (lj-profile-p))))
  :group 'ljupdate)

(defcustom lj-startup-file "~/.lj.eld"
  "*The location of your LJ startup file.

If you want to use a nonstandard location, you should change this
variable before calling any ljupdate functions."
  :type 'file
  :group 'ljupdate)

(defcustom lj-proxy nil
  "*If non-nil, the hostname of the proxy server to use.
If nil, don't use a proxy."
  :type '(choice string (const nil))
  :group 'ljupdate)

(defcustom lj-proxy-port 80
  "*Port on the proxy to use."
  :type 'integer
  :group 'ljupdate)

(defcustom lj-timeout-interval 180
  "*How long to wait for the LiveJournal server response. In seconds."
  :type 'integer
  :group 'ljupdate)

(defcustom lj-default-subject nil
  "*The default subject for an entry."
  :type '(choice string (const nil))
  :group 'ljupdate)

(defcustom lj-default-mood nil
  "*The default mood for a Live Journal entry."
  :type '(choice string (const nil))
  :group 'ljupdate)

(defcustom lj-default-access-level "public"
  "*Access level to use by default for LiveJournal posts.

Current possible values are ``public'', ``private'', and
``friends''."
  :type '(choice (const :tag "Public (anyone)" "public")
                 (const :tag "Private (you only)" "private")
                 (const :tag "Friends-only" "friends"))
  :group 'ljupdate)

(defcustom lj-default-comments-flag "yes"
  "*Whether or not to allow comments by default.

If you want to disallow comments, the Allow-Comments header should
be set to the English word ``no'', case insensitively."
  :type '(choice (const :tag "Allow comments" "yes")
                 (const :tag "Disallow comments" "no"))
  :group 'ljupdate)

(defcustom lj-default-mail-notification-flag "yes"
  "*Whether or not to receive email notification of comments by default.

If you want to turn off mail notification, the
Receive-Mail-Notification header should be set to the English word
``no'', case insensitively."
  :type '(choice (const :tag "Receive Mail Notification" "yes")
                 (const :tag "Do Not Receive Mail Notification" "no"))
  :group 'ljupdate)

(defcustom lj-update-friends-on-login-flag t
  "*When non-nil, ljupdate will update your cached friends list on login."
  :type '(choice (const :tag "Update friends on login" t)
                 (const :tag "Don't update friends on login" nil))
  :group 'ljupdate)

(defcustom lj-use-menu-bar-flag t
  "*When non-nil, ljupdate will create a k-rad menu in your menu bar."
  :type 'boolean
  :group 'ljupdate)

(defcustom lj-music-function 'lj-get-music-from-external-program
  "*A function which returns a string describing your current music."
  :type '(choice (const :tag "Use `lj-music-external-program'" 'lj-get-music-from-external-program)
                 function)
  :group 'ljupdate)

(defcustom lj-music-external-program
  (cond ((eq system-type 'windows-nt) "askwinamp.exe")
        ((eq system-type 'darwin) "itunes_current.pl")
        (t "xmmscurrent"))
  "*External program that should be used to get your current music.
This will only be used when `lj-music-function' hasn't been
changed from its default setting."
  :type 'string
  :group 'ljupdate)

(defcustom lj-remember-passwords-flag nil
  "*Non-nil means ljupdate should cache password hashes in `lj-startup-file'.

This should not be a security risk if the permissions on
`lj-startup-file' are set sanely, namely to 600 or something very
similar, and besides, it doesn't cache your actual password, but
merely the md5 hash of it (assuming `lj--use-md5-p' is non-nil,
which it really really should be). Nevertheless, we default to
nil to be on the safe side."
  :type '(choice (const :tag "Remember my passwords" t)
                 (const :tag "Don't remember my passwords" nil))
  :group 'ljupdate)

(defcustom lj-archive-file-name "~/ljarchive.mbox"
  "*Mailbox into which to archive LiveJournal updates.
Set to nil if you don't want this to happen."
  :type '(choice file (const :tag "None" nil))
  :group 'ljupdate)

(defun lj--filter-build-wiki-rule (wiki url-before &optional url-after)
  "Define a substitution for WIKI pointing to URL."
  (cons (concat wiki ":\\([A-Z][a-z]+\\([A-Z][a-z]+\\)+\\)")
        (format "<a href=\"%s\\1%s\">%s:\\1</a>" url-before url-after wiki)))
(put 'lj--filter-build-wiki-rule 'lisp-indent-function 1)

(defcustom lj-filter-substitution-alist
  (list (lj--filter-build-wiki-rule "EmacsWiki"
          "http://www.emacswiki.org/cgi-bin/wiki.pl?")
        (lj--filter-build-wiki-rule "MeatBall"
          "http://www.usemod.com/cgi-bin/mb.pl?")
        (lj--filter-build-wiki-rule "UseMod"
          "http://www.usemod.com/cgi-bin/wiki.pl?")
        (lj--filter-build-wiki-rule "WikiWiki"
          "http://c2.com/cgi/wiki?")
        (cons "\\([Rr][Ff][Cc]\\s-?\\([0-9]+\\)\\)"
              "<a href=\"http://www.faqs.org/rfcs/rfc\\2.html\">\\1</a>"))
  "An alist defining substitution rules to be applied to journal entries.
Each pair should be of the form (REGEXP . SUBSTITUTION), where
REGEXP is a regular expression matching text that you want to
substitute, and SUBSTITUTION is either a string to substitute
(which may contain references to the match data), or a function
that returns such a string."
  :type '(alist :key-type string :value-type string)
  :group 'ljupdate)

(defcustom lj-edit-friends-mode-hook '()
  "*Hooks to be run when entering `lj-edit-friends-mode'."
  :type 'hook
  :group 'ljupdate)

(defcustom lj-list-entries-mode-hook nil
  "Hooks to be executed when `lj-list-entries-mode' is entered."
  :type 'hook
  :group 'ljupdate)

(defcustom lj-before-post-hook '()
  "*Hook to be run before posting the journal update."
  :type 'hook
  :group 'ljupdate)

(defcustom lj-save-startup-hook '()
  "*Hooks to be run when ljupdate saves your startup file."
  :type 'hook
  :group 'ljupdate)

(defcustom lj-update-mode-hook nil
  "Hooks to be executed when `lj-update-mode' is entered."
  :type 'hook
  :group 'ljupdate)

(provide 'ljcustom)
;;; ljcustom.el ends here
