;;; ljfilter.el --- update body filtering for ljupdate

;; Copyright (C) 2002  Edward O'Connor <ted@oconnor.cx>

;; Author: Edward O'Connor <ted@oconnor.cx>
;; Keywords: convenience

;; This file is part of ljupdate.

;; ljupdate is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; {at your option} any later version.

;; ljupdate is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public
;; License along with ljupdate, or with your Emacs. See the file
;; COPYING, or, if you're using GNU Emacs, try typing C-h C-c to
;; bring it up. If you're using XEmacs, C-h C-l does this. If you
;; do not have a copy, you can obtain one by writing to the Free
;; Software Foundation at this address:

;;                Free Software Foundation, Inc.
;;                59 Temple Place, Suite 330
;;                Boston, MA  02111-1307
;;                USA

;;; Commentary:

;; 

;;; Code:

(require 'ljcompat)
(require 'lj-post)

(defun lj--filter-with-rule (rule)
  "Apply substitution RULE to journal update body."
  (let ((regexp (car rule))
        (susbt-rule (cdr rule)))
    (save-excursion
      (goto-char (ljc-mail-header-end))
      (forward-line 1)
      (while (re-search-forward regexp nil t)
        (if (functionp susbt-rule)
            (replace-match (subst-rule) t nil)
          (replace-match susbt-rule t nil))))))

(defun lj--filter-update-body ()
  "Apply the user's substitution rules to journal update body."
  (mapc 'lj--filter-with-rule lj-filter-substitution-alist))

(add-hook 'lj-before-post-hook 'lj--filter-update-body)

(provide 'ljfilter)
;;; ljfilter.el ends here
